@@ -3,7 +3,7 @@ require 5;
 package Pod::Simple::PullParserToken;
  # Base class for tokens gotten from Pod::Simple::PullParser's $parser->get_token
 @ISA = ();
-$VERSION = '3.31';
+$VERSION = '3.36';
 use strict;
 
 sub new {  # Class->new('type', stuff...);  ## Overridden in derived classes anyway
@@ -50,7 +50,7 @@ Given a $parser that's an object of class Pod::Simple::PullParser
 (or a subclass)...
 
   while(my $token = $parser->get_token) {
-    $DEBUG and print "Token: ", $token->dump, "\n";
+    $DEBUG and print STDERR "Token: ", $token->dump, "\n";
     if($token->is_start) {
       ...access $token->tagname, $token->attr, etc...
 
@@ -104,7 +104,7 @@ This returns a handy stringified value of this object.  This
 is useful for debugging, as in:
 
   while(my $token = $parser->get_token) {
-    $DEBUG and print "Token: ", $token->dump, "\n";
+    $DEBUG and print STDERR "Token: ", $token->dump, "\n";
     ...
   }
 
