@@ -3,7 +3,7 @@ require 5;
 package Pod::Simple::Transcode;
 use strict;
 use vars qw($VERSION @ISA);
-$VERSION = '3.31';
+$VERSION = '3.36';
 
 BEGIN {
   if(defined &DEBUG) {;} # Okay
@@ -17,12 +17,12 @@ foreach my $class (
   '',
 ) {
   $class or die "Couldn't load any encoding classes";
-  DEBUG and print "About to try loading $class...\n";
+  DEBUG and print STDERR "About to try loading $class...\n";
   eval "require $class;";
   if($@) {
-    DEBUG and print "Couldn't load $class: $@\n";
+    DEBUG and print STDERR "Couldn't load $class: $@\n";
   } else {
-    DEBUG and print "OK, loaded $class.\n";
+    DEBUG and print STDERR "OK, loaded $class.\n";
     @ISA = ($class);
     last;
   }
